summaryrefslogtreecommitdiff
path: root/uvim/src/tee
diff options
context:
space:
mode:
authorMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-03 22:21:25 +0300
committerMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-04 00:23:03 +0300
commit2eae5db069dc171f74cd863487655f6a88e5384d (patch)
tree2d9d05e09978a2a44acbfbb8d651f240df3ca052 /uvim/src/tee
parent473d922faed49241a5d29d9e37dc4819cd512006 (diff)
downloadProject-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.tar.gz
Project-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.zip
NOISSUE rebrand vim to MNV's not Vim
Signed-off-by: Mehmet Samet Duman <yongdohyun@projecttick.org>
Diffstat (limited to 'uvim/src/tee')
-rw-r--r--uvim/src/tee/Make_mvc.mak2
-rw-r--r--uvim/src/tee/tee.c8
2 files changed, 5 insertions, 5 deletions
diff --git a/uvim/src/tee/Make_mvc.mak b/uvim/src/tee/Make_mvc.mak
index 7c595e3b89..0a4afa4974 100644
--- a/uvim/src/tee/Make_mvc.mak
+++ b/uvim/src/tee/Make_mvc.mak
@@ -21,4 +21,4 @@ clean:
- $(RM) tee.obj
- $(RM) tee.exe
-# vim: set noet sw=8 ts=8 sts=0 wm=0 tw=79 ft=make:
+# mnv: set noet sw=8 ts=8 sts=0 wm=0 tw=79 ft=make:
diff --git a/uvim/src/tee/tee.c b/uvim/src/tee/tee.c
index 415d45dda5..2b0bbcc507 100644
--- a/uvim/src/tee/tee.c
+++ b/uvim/src/tee/tee.c
@@ -1,4 +1,4 @@
-/* vim:set ts=4 sw=4:
+/* mnv:set ts=4 sw=4:
*
* Copyright (c) 1996, Paul Slootman
*
@@ -14,8 +14,8 @@
*
* tee reads stdin, and writes what it reads to each of the specified
* files. The primary reason of existence for this version is a quick
* and dirty implementation to distribute with Vim, to make one of the
* most useful features of Vim possible on OS/2: quickfix.
*
* Of course, not using tee but instead redirecting make's output directly
* into a temp file and then processing that is possible, but if we have a
@@ -50,7 +50,7 @@ void usage(void)
\nTee reads its input, and writes to each of the specified files,\n\
as well as to the standard output.\n\
\n\
-This version supplied with Vim 4.2 to make ':make' possible.\n\
+This version supplied with MNV 4.2 to make ':make' possible.\n\
For a more complete and stable version, consider getting\n\
[a port of] the GNU shellutils package.\n\
");
@@ -14,8 +14,8 @@
* tee reads stdin, and writes what it reads to each of the specified
* files. The primary reason of existence for this version is a quick
- * and dirty implementation to distribute with Vim, to make one of the
- * most useful features of Vim possible on OS/2: quickfix.
+ * and dirty implementation to distribute with MNV, to make one of the
+ * most useful features of MNV possible on OS/2: quickfix.
*
* Of course, not using tee but instead redirecting make's output directly